pub struct ProverState<C: SetConfig> {
pub randomness: Vec<C::Element>,
pub mles: Vec<DenseMultilinearExtension<C::Element>>,
pub num_vars: usize,
pub max_degree: usize,
pub round: usize,
pub asserted_sum: Option<C::Element>,
pub skip_next_fold: bool,
}Expand description
Sumcheck Prover State, generic over the field config C.
Fields
randomness: Vec<C::Element>Sampled randomness given by the verifier.
mles: Vec<DenseMultilinearExtension<C::Element>>Stores the list of multilinear extensions the sumcheck polynomial is comprised of.
num_vars: usizeNumber of variables.
max_degree: usizeMax degree.
round: usizeThe current round number.
asserted_sum: Option<C::Element>Claimed sum for the first round polynomial.
skip_next_fold: boolWhen true, the next Self::prove_round invocation pushes the
verifier challenge into randomness but skips the
fix_variables fold of mles. Used by round-1 fast
paths (see that pre-fold the MLEs as part of their setup.
The flag is reset to false after the skipped fold.
Implementations
Sourceimpl<C: SetConfig> ProverState<C>
impl<C: SetConfig> ProverState<C>
Sourceimpl<C: SemiringConfig> ProverState<C>
impl<C: SemiringConfig> ProverState<C>
Sourcepub fn prove_round(
&mut self,
v_msg: &Option<C::Element>,
comb_fn: impl Fn(&[C::Element]) -> C::Element + Send + Sync,
config: &C,
) -> ProverMsg<C::Element>
pub fn prove_round( &mut self, v_msg: &Option<C::Element>, comb_fn: impl Fn(&[C::Element]) -> C::Element + Send + Sync, config: &C, ) -> ProverMsg<C::Element>
Receive message from verifier, generate prover message, and proceed to next round.
Adapted Jolt’s sumcheck implementation, with some additions like round 1 fast path.